GroupContactsModel class

GroupContactsModel contains groups and contacts in a single model

Constructors

GroupContactsModel({AtContact? contact, AtGroup? group, ContactsType? contactType})
GroupContactsModel.fromJson(String source)
factory
GroupContactsModel.fromMap(Map<String, dynamic>? map)
factory

Properties

contact → AtContact?
final
contactType → ContactsType?
final
group → AtGroup?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({AtContact? contact, AtGroup? group, ContactsType? contactType}) → GroupContactsModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override