TextConstants class

Constructors

TextConstants()
factory

Properties

EMPTY_NAME ↔ String
getter/setter pair
GROUP_ALREADY_EXISTS ↔ String
getter/setter pair
GROUP_NAME_REGEX ↔ String
getter/setter pair
GROUP_PRESENT ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
INVALID_NAME ↔ String
getter/setter pair
MEMBER_ADDED ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
SERVICE_ERROR ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

Sibebar width