CustomTextStyles class

Constructors

CustomTextStyles()
factory

Properties

grey14 ↔ TextStyle
getter/setter pair
grey16 ↔ TextStyle
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
orange12 ↔ TextStyle
getter/setter pair
orange14 ↔ TextStyle
getter/setter pair
orange16 ↔ TextStyle
getter/setter pair
orange18 ↔ TextStyle
getter/setter pair
primaryBold18 ↔ TextStyle
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

desktopPrimaryRegular14 ↔ TextStyle
getter/setter pair
error14 ↔ TextStyle
getter/setter pair
primaryBold16 ↔ TextStyle
getter/setter pair
primaryMedium14 ↔ TextStyle
getter/setter pair
primaryRegular20 ↔ TextStyle
getter/setter pair
secondaryRegular12 ↔ TextStyle
getter/setter pair
secondaryRegular14 ↔ TextStyle
getter/setter pair
secondaryRegular16 ↔ TextStyle
getter/setter pair

Static Methods

blackBold({int size = 16}) → TextStyle